function impConv

%end time
T=0.5;

%initial value
y0=pi/4;

%vector containing number of steps
Nh=2.^(4:8);

%right hand side of IVP
f=@(x) exp(x)*sin(x);

%Jacobi matrix of f
Df=@(x) exp(x)*(sin(x)+cos(x));


%reference solution with small tolerances
opts=odeset('RelTol',1e-12,'AbsTol',1e-12);
[~, yref]=ode45(@(t,x) f(x),[0 T],y0,opts);

%allocate memory
errImpEul=zeros(size(Nh));
errImpMpr=zeros(size(Nh));
for ii=1:length(Nh)
    
    %implicit Euler method
    yEul=impEul(y0,f,Df,T,Nh(ii));
    
    %implicit mid-point rule
    yMpr=impMpr(y0,f,Df,T,Nh(ii));

    %absolute error
    errImpEul(ii)=abs(yEul-yref(end));
    errImpMpr(ii)=abs(yMpr-yref(end));
    
end

figure;
loglog(Nh,errImpEul,'*-b',Nh,errImpMpr,'*-r');
legend('impEul','impMpr')
grid on
xlabel('Number of steps')
ylabel('abs error')

p=polyfit(log(Nh),log(errImpEul),1);
fprintf('Convergence rate of impEul = %3.4f\n',p(1))

p=polyfit(log(Nh),log(errImpMpr),1);
fprintf('Convergence rate of impMpr = %3.4f\n',p(1))

print -depsc impConv
