function ExpMidPointConvSol
%
% Name:
%
% Calculate the emprical convergence order of the Explicit Midpoint rule.
%
% See also EXPMIDPOINTSOL, RHSSOL, SOLSOL.
  
  y0 = 0;
  T = [0 1];
  h = 2.^-[2:8];
  err = nan(size(h));

  for j=1:length(h)
    % solution using explicit middle point rule
    [t,y] = ExpMidPointSol(@rhsSol,0,[0 1],h(j));
    % exact solution
    yExact = solSol(t);
    % calculate error
    err(j) = norm( y(1,end) - yExact(1,end) );
  end

  figure;
% Plot log-log-plot here:
  loglog(h,err,'bx:',h,h.^2,'g','LineWidth',1.5)
  title(['{\bf log-log Plot of Error against Step-Size for '...
         'the Explicit Middle Point rule}']);
  xlabel('h');
  ylabel('error');
  legend('Explicit Midpoint','O(h^2)','Location','NorthWest');
  grid on;
  
% Rufe polyfit hier auf:
  fit = polyfit(log(h),log(err),1);
  fprintf('Convergence order: %f\n',fit(1));

  print -depsc '../../images/a8Conv.eps'
  
