function [t,y] = ExpMidPointSol(f,y0,T,h)
%
%   Aufgabe 1.
%   NAME:
%
%   [T,Y] = EXPMIDPOINTSOL(F,Y0,[T0 T1],H) solves the ODE y'=f(t,y) over the
%   interval [T0 T1] with y(T0) = Y0 using the explicit middle-point rule with
%   step size (at most) H.  The input argument F should be a function handle
%   taking the arguments (t,y) and returning a column vector corresponding to
%   f(t,y).
%
%   Butcher Table:
%     0  | 
%    1/2 | 1/2
%    ____|________
%        |  0   1

% Initialize variables
N = ceil((T(2)-T(1))/h); % number of steps
h = (T(2)-T(1))/N; % adjust step size to fit interval length
d = size(y0,1); % dimension of solution
t = linspace(T(1),T(2),N+1); % time grid
y = nan(d,N+1); % solution
y(:,1) = y0; % set initial value

% Compute solution
for j=1:N
  y(:,j+1) = ExpMidPointStep(f,y(:,j),t(:,j),h);
end


function y1 = ExpMidPointStep(f,y0,t0,h)
% Computes one step of the explicit middle-point rule

% Add slopes and update here...
  k1 = f(t0,y0);
  k2 = f(t0 + 0.5*h,y0 + 0.5*h*k1);
  y1 = y0 + h*k2;

% or...
% k = nan(size(y0,1),2);
% k(:,1) = f(t0,y0);
% k(:,2) = f(t0 + 0.5*h,y0 + 0.5*h*k(:,1));
% y1 = y0 + h*k(:,2);
